package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.feign.WmshBoundFeign;
import com.steerinfo.dil.mapper.TmstrainLoadingResultMapper;
import com.steerinfo.dil.model.TmstrainLoadingResult;
import com.steerinfo.dil.service.ITmstrainLoadingResultService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * TmstrainLoadingResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-08-30 02:23
 * 类描述
 * 修订历史：
 * 日期：2021-08-30
 * 作者：generator
 * 参考：
 * 描述：TmstrainLoadingResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstrainLoadingResultService")
public class TmstrainLoadingResultServiceImpl implements ITmstrainLoadingResultService {

    @Autowired
    private TmstrainLoadingResultMapper tmstrainLoadingResultMapper;

    @Autowired
    private WmshBoundFeign wmshBoundFeign;


    @Override
    public List<Map<String, Object>> getTmstrainWagonLoad(Map<String, Object> map) {
        return tmstrainLoadingResultMapper.getTmsWagonLoadInfo(map);
    }

    @Override
    @Transactional
    public int addTmstrainLoadingResult(TmstrainLoadingResult tmstrainLoadingResult) {
        BigDecimal maxId = tmstrainLoadingResultMapper.selectMaxId();
        //生成主键id
        tmstrainLoadingResult.setResultId(maxId);
        //通过批次ID获得采购订单号和物资ID
        BigDecimal batchId = tmstrainLoadingResult.getBatchId();
        BigDecimal materialId = tmstrainLoadingResultMapper.getMaterialID(batchId);
        //查询并插入采购订单号
        BigDecimal purchaseOrderId = tmstrainLoadingResultMapper.getPurchaseOrderId(batchId);
        tmstrainLoadingResult.setPurchaseOrderRailPlanId(purchaseOrderId);
        tmstrainLoadingResult.setMaterialId(materialId);
        //常规字段插入
        tmstrainLoadingResult.setInsertUsername("admin");
        tmstrainLoadingResult.setInsertTime(new Date());
        tmstrainLoadingResult.setUpdateUsername("admin");
        tmstrainLoadingResult.setUpdateTime(new Date());
        tmstrainLoadingResult.setInsertUpdateRemark("无");
        tmstrainLoadingResult.setDeleted(new BigDecimal(0));

        Map<String, Object> map = new HashMap<>();
        map.put("isClean",tmstrainLoadingResult.getResultIsclear());
        map.put("resultTonnage", tmstrainLoadingResult.getResultBillableTonnage());
        map.put("batchId", batchId);
        //通过发站查询发站的所属港口
        BigDecimal portId = tmstrainLoadingResultMapper.getPortIdBySendStationId(tmstrainLoadingResult.getSendStationId());
        map.put("portId", portId);
        wmshBoundFeign.addResult(map);

        return tmstrainLoadingResultMapper.insertSelective(tmstrainLoadingResult);
    }

    @Override
    public List<Map<String, Object>> getTmstrainLoadingResultByResultId(BigDecimal resultId) {
        return tmstrainLoadingResultMapper.selectByResultId(resultId);
    }

    @Override
    public int updateTmstrainLoadingResult(TmstrainLoadingResult tmstrainLoadingResult) {
        tmstrainLoadingResult.setUpdateTime(new Date());
        return tmstrainLoadingResultMapper.updateByPrimaryKeySelective(tmstrainLoadingResult);
    }

    @Override
    public int deleteTmstrainLoadingResultByResultId(BigDecimal resultId) {
        TmstrainLoadingResult tmstrainLoadingResult = tmstrainLoadingResultMapper.selectByPrimaryKey(resultId);
        tmstrainLoadingResult.setDeleted(new BigDecimal(1));
        return tmstrainLoadingResultMapper.updateByPrimaryKeySelective(tmstrainLoadingResult);
    }

    @Override
    public int addTrainLoadResultForConverted(TmstrainLoadingResult tmstrainLoadingResult) {
        //设置主键id
        BigDecimal maxId = tmstrainLoadingResultMapper.selectMaxId();
        //生成主键id
        tmstrainLoadingResult.setResultId(maxId);
        //获取发运计划id
        BigDecimal planId= tmstrainLoadingResult.getPurchaseOrderRailPlanId();
        //通过发运计划号查找物资信息
        Map<String,Object> map=tmstrainLoadingResultMapper.getMaterialInfoByRailPlanId(planId.intValue());
        //获取物资id
        Integer materialId =(Integer) map.get("materialId");
        tmstrainLoadingResult.setMaterialId(DataChange.dataToBigDecimal(materialId));
        //获取物资件数
        Integer materialNumber = (Integer)map.get("materialNumber");
        tmstrainLoadingResult.setResultMaterialNumber(DataChange.dataToBigDecimal(materialNumber));
        //获取物资理重
        Integer materialWeight = (Integer)map.get("materialWeight");
        tmstrainLoadingResult.setResultMaterialTheoryweight(DataChange.dataToBigDecimal(materialWeight));
        tmstrainLoadingResult.setInsertTime(new Date());
        tmstrainLoadingResult.setInsertUsername("admin");
        return tmstrainLoadingResultMapper.insertSelective(tmstrainLoadingResult);
    }

    @Override
    public List<Map<String, Object>> selectLoadByResultId(BigDecimal resultId) {
        return tmstrainLoadingResultMapper.selectLoadByResultId(resultId);
    }

    @Override
    public List<Map<String, Object>> selectLoadedForConverted(Map<String, Object> map) {
        return tmstrainLoadingResultMapper.selectLoadedForConverted(map);
    }

    @Override
    public List<Map<String, Object>> getSendStationName() {
        return tmstrainLoadingResultMapper.getSendStationName();
    }

    @Override
    public List<Map<String, Object>> getArrivalStationName() {
        return tmstrainLoadingResultMapper.getArrivalStationName();
    }

    @Override
    public List<Map<String, Object>> getBatchId() {
        return tmstrainLoadingResultMapper.getBatchId();
    }

    @Override
    public List<Map<String, Object>> getWagonNo() {
        return tmstrainLoadingResultMapper.getWagonNo();
    }
}
